#! /bin/sh

for dir in applications feel testsuite research examples; do
    files=`find $dir -name "*.[hc]pp"`
    ASTYLE-NOTFOUND --options=/Users/prudhomme/sources/feelpp/scripts/astyle/feelpp.astyle.options $files
done
